@@ -1,17 +1,36 @@
+from functools import wraps
 from typing import List, Tuple
 
-from branca.element import CssLink, Element, Figure, JavascriptLink, MacroElement
+from branca.element import (
+    CssLink,
+    Element,  # NoQA: F401  needed as a reexport
+    Figure,
+    JavascriptLink,
+    MacroElement,
+)
 
 from folium.template import Template
-from folium.utilities import JsCode
+from folium.utilities import JsCode, camelize
 
 
-class JSCSSMixin(Element):
+def leaflet_method(fn):
+    @wraps(fn)
+    def inner(self, *args, **kwargs):
+        self.add_child(MethodCall(self, fn.__name__, *args, **kwargs))
+
+    return inner
+
+
+class JSCSSMixin(MacroElement):
     """Render links to external Javascript and CSS resources."""
 
     default_js: List[Tuple[str, str]] = []
     default_css: List[Tuple[str, str]] = []
 
+    # Since this is typically used as a mixin, we cannot
+    # override the _template member variable here. It would
+    # be overwritten by any subclassing class that also has
+    # a _template variable.
     def render(self, **kwargs):
         figure = self.get_root()
         assert isinstance(
@@ -138,3 +157,47 @@ class ElementAddToElement(MacroElement):
         super().__init__()
         self.element_name = element_name
         self.element_parent_name = element_parent_name
+
+
+class IncludeStatement(MacroElement):
+    """Generate an include statement on a class."""
+
+    _template = Template(
+        """
+        {{ this.leaflet_class_name }}.include(
+            {{ this.options | tojavascript }}
+        )
+    """
+    )
+
+    def __init__(self, leaflet_class_name: str, **kwargs):
+        super().__init__()
+        self.leaflet_class_name = leaflet_class_name
+        self.options = kwargs
+
+    def render(self, *args, **kwargs):
+        return super().render(*args, **kwargs)
+
+
+class MethodCall(MacroElement):
+    """Abstract class to add an element to another element."""
+
+    _template = Template(
+        """
+        {% macro script(this, kwargs) %}
+            {{ this.target }}.{{ this.method }}(
+                {% for arg in this.args %}
+                    {{ arg | tojavascript }},
+                {% endfor %}
+                {{ this.kwargs | tojavascript }}
+            );
+        {% endmacro %}
+    """
+    )
+
+    def __init__(self, target: MacroElement, method: str, *args, **kwargs):
+        super().__init__()
+        self.target = target.get_name()
+        self.method = camelize(method)
+        self.args = args
+        self.kwargs = kwargs
