@@ -7,7 +7,18 @@ import functools
 import json
 import operator
 import warnings
-from typing import Any, Callable, Dict, Iterable, List, Optional, Sequence, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    get_args,
+)
 
 import numpy as np
 import requests
@@ -25,14 +36,16 @@ from branca.utilities import color_brewer
 
 from folium.elements import JSCSSMixin
 from folium.folium import Map
-from folium.map import FeatureGroup, Icon, Layer, Marker, Popup, Tooltip
+from folium.map import Class, FeatureGroup, Icon, Layer, Marker, Popup, Tooltip
 from folium.template import Template
 from folium.utilities import (
+    JsCode,
     TypeBoundsReturn,
     TypeContainer,
     TypeJsonValue,
     TypeLine,
     TypePathOptions,
+    TypePosition,
     _parse_size,
     escape_backticks,
     get_bounds,
@@ -516,6 +529,10 @@ class GeoJson(Layer):
         embedding is only supported if you provide a file link or URL.
     zoom_on_click: bool, default False
         Set to True to enable zooming in on a geometry when clicking on it.
+    on_each_feature: JsCode, optional
+        Javascript code to be called on each feature.
+        See https://leafletjs.com/examples/geojson/
+        `onEachFeature` for more information.
     **kwargs
         Keyword arguments are passed to the geoJson object as extra options.
 
@@ -570,9 +587,9 @@ class GeoJson(Layer):
 
         {%- if this.marker %}
         function {{ this.get_name() }}_pointToLayer(feature, latlng) {
-            var opts = {{ this.marker.options | tojson | safe }};
+            var opts = {{ this.marker.options | tojavascript }};
             {% if this.marker._name == 'Marker' and this.marker.icon %}
-            const iconOptions = {{ this.marker.icon.options | tojson | safe }}
+            const iconOptions = {{ this.marker.icon.options | tojavascript }}
             const iconRootAlias = L{%- if this.marker.icon._name == "Icon" %}.AwesomeMarkers{%- endif %}
             opts.icon = new iconRootAlias.{{ this.marker.icon._name }}(iconOptions)
             {% endif %}
@@ -585,6 +602,10 @@ class GeoJson(Layer):
         {%- endif %}
 
         function {{this.get_name()}}_onEachFeature(feature, layer) {
+            {%- if this.on_each_feature %}
+            ({{this.on_each_feature}})(feature, layer);
+            {%- endif %}
+
             layer.on({
                 {%- if this.highlight %}
                 mouseout: function(e) {
@@ -679,6 +700,7 @@ class GeoJson(Layer):
         embed: bool = True,
         popup: Optional["GeoJsonPopup"] = None,
         zoom_on_click: bool = False,
+        on_each_feature: Optional[JsCode] = None,
         marker: Union[Circle, CircleMarker, Marker, None] = None,
         **kwargs: Any,
     ):
@@ -705,6 +727,7 @@ class GeoJson(Layer):
         self.popup_keep_highlighted = popup_keep_highlighted
 
         self.marker = marker
+        self.on_each_feature = on_each_feature
         self.options = remove_empty(**kwargs)
 
         self.data = self.process_data(data)
@@ -1108,7 +1131,15 @@ class GeoJsonDetail(MacroElement):
     function(layer){
     let div = L.DomUtil.create('div');
     {% if this.fields %}
-    let handleObject = feature=>typeof(feature)=='object' ? JSON.stringify(feature) : feature;
+    let handleObject = feature => {
+        if (feature === null) {
+            return '';
+        } else if (typeof(feature)=='object') {
+            return JSON.stringify(feature);
+        } else {
+            return feature;
+        }
+    }
     let fields = {{ this.fields | tojson | safe }};
     let aliases = {{ this.aliases | tojson | safe }};
     let table = '<table>' +
@@ -1718,7 +1749,6 @@ class DivIcon(MacroElement):
         """
         {% macro script(this, kwargs) %}
             var {{ this.get_name() }} = L.divIcon({{ this.options|tojavascript }});
-            {{this._parent.get_name()}}.setIcon({{this.get_name()}});
         {% endmacro %}
         """
     )  # noqa
@@ -1813,7 +1843,7 @@ class ClickForMarker(MacroElement):
         if isinstance(popup, Element):
             popup = popup.render()
         if popup:
-            self.popup = "`" + escape_backticks(popup) + "`"
+            self.popup = "`" + escape_backticks(popup) + "`"  # type: ignore
         else:
             self.popup = '"Latitude: " + lat + "<br>Longitude: " + lng '
 
@@ -1862,14 +1892,14 @@ class CustomIcon(Icon):
 
     Parameters
     ----------
-    icon_image :  string, file or array-like object
-        The data you want to use as an icon.
-        * If string, it will be written directly in the output file.
-        * If file, it's content will be converted as embedded in the
-        output file.
-        * If array-like, it will be converted to PNG base64 string
-        and embedded in the output.
+    icon_image : string or array-like object
+        The data to use as an icon.
 
+        * If string is a path to an image file, its content will be converted and
+          embedded.
+        * If string is a URL, it will be linked.
+        * Otherwise a string will be assumed to be JSON and embedded.
+        * If array-like, it will be converted to PNG base64 string and embedded.
     icon_size : tuple of 2 int, optional
         Size of the icon image in pixels.
     icon_anchor : tuple of 2 int, optional
@@ -1895,7 +1925,6 @@ class CustomIcon(Icon):
         """
         {% macro script(this, kwargs) %}
         var {{ this.get_name() }} = L.icon({{ this.options|tojavascript }});
-        {{ this._parent.get_name() }}.setIcon({{ this.get_name() }});
         {% endmacro %}
         """
     )  # noqa
@@ -1911,7 +1940,7 @@ class CustomIcon(Icon):
         popup_anchor: Optional[Tuple[int, int]] = None,
     ):
         super(Icon, self).__init__()
-        self._name = "CustomIcon"
+        self._name = "icon"
         self.options = remove_empty(
             icon_url=image_to_url(icon_image),
             icon_size=icon_size,
@@ -1992,3 +2021,61 @@ class ColorLine(FeatureGroup):
             out.setdefault(cm(color), []).append([[lat1, lng1], [lat2, lng2]])
         for key, val in out.items():
             self.add_child(PolyLine(val, color=key, weight=weight, opacity=opacity))
+
+
+class Control(JSCSSMixin, Class):
+    """
+    Add a Leaflet Control object to the map
+
+    Parameters
+    ----------
+    control: str
+        The javascript class name of the control to be rendered.
+    position: str
+        One of "bottomright", "bottomleft", "topright", "topleft"
+
+    Examples
+    --------
+
+    >>> import folium
+    >>> from folium.features import Control, Marker
+    >>> from folium.plugins import Geocoder
+
+    >>> m = folium.Map(
+    ...     location=[46.603354, 1.8883335], attr=None, zoom_control=False, zoom_start=5
+    ... )
+    >>> Control("Zoom", position="topleft").add_to(m)
+    """
+
+    _template = Template(
+        """
+      {% macro script(this, kwargs) %}
+          var {{ this.get_name() }} = new L.Control.{{this._name}}(
+              {% for arg in this.args %}
+                  {{ arg | tojavascript }},
+              {% endfor %}
+              {{ this.options|tojavascript }}
+          ).addTo({{ this._parent.get_name() }});
+      {% endmacro %}
+    """
+    )
+
+    def __init__(
+        self,
+        control: Optional[str] = None,
+        *args,
+        position: Optional[TypePosition] = None,
+        **kwargs,
+    ):
+        super().__init__()
+        if control:
+            self._name = control
+
+        if position is not None:
+            position = position.lower()  # type: ignore
+            if position not in (args := get_args(TypePosition)):
+                raise TypeError(f"position must be one of {args}")
+            kwargs["position"] = position
+
+        self.args = args
+        self.options = remove_empty(**kwargs)
