@@ -4,12 +4,12 @@ Classes for drawing maps.
 """
 
 import warnings
-from collections import OrderedDict
-from typing import TYPE_CHECKING, Optional, Sequence, Union, cast
+from collections import OrderedDict, defaultdict
+from typing import TYPE_CHECKING, DefaultDict, Optional, Sequence, Union, cast
 
 from branca.element import Element, Figure, Html, MacroElement
 
-from folium.elements import ElementAddToElement, EventHandler
+from folium.elements import ElementAddToElement, EventHandler, IncludeStatement
 from folium.template import Template
 from folium.utilities import (
     JsCode,
@@ -22,11 +22,58 @@ from folium.utilities import (
     validate_location,
 )
 
+
+class classproperty:
+    def __init__(self, f):
+        self.f = f
+
+    def __get__(self, obj, owner):
+        return self.f(owner)
+
+
 if TYPE_CHECKING:
     from folium.features import CustomIcon, DivIcon
 
 
-class Evented(MacroElement):
+class Class(MacroElement):
+    """The root class of the leaflet class hierarchy"""
+
+    _includes: DefaultDict[str, dict] = defaultdict(dict)
+
+    @classmethod
+    def include(cls, **kwargs):
+        cls._includes[cls].update(**kwargs)
+
+    @classproperty
+    def includes(cls):
+        return cls._includes[cls]
+
+    @property
+    def leaflet_class_name(self):
+        # TODO: I did not check all Folium classes to see if
+        # this holds up. This breaks at least for CustomIcon.
+        return f"L.{self._name}"
+
+    def render(self, **kwargs):
+        figure = self.get_root()
+        assert isinstance(
+            figure, Figure
+        ), "You cannot render this Element if it is not in a Figure."
+        if self.includes:
+            stmt = IncludeStatement(self.leaflet_class_name, **self.includes)
+            # A bit weird. I tried adding IncludeStatement directly to both
+            # figure and script, but failed. So we render this ourself.
+            figure.script.add_child(
+                Element(stmt._template.render(this=stmt, kwargs=self.includes)),
+                # make sure each class include gets rendered only once
+                name=self._name + "_includes",
+                # make sure this renders before the element itself
+                index=-1,
+            )
+        super().render(**kwargs)
+
+
+class Evented(Class):
     """The base class for Layer and Map
 
     Adds the `on` and `once` methods for event handling capabilities.
@@ -382,7 +429,9 @@ class Marker(MacroElement):
         """
         )
 
-        def __init__(self, marker: "Marker", icon: "Icon"):
+        def __init__(
+            self, marker: "Marker", icon: Union[Icon, "CustomIcon", "DivIcon"]
+        ):
             super().__init__()
             self._name = "SetIcon"
             self.marker = marker
@@ -406,8 +455,7 @@ class Marker(MacroElement):
         # this attribute is not used by Marker, but by GeoJson
         self.icon = None
         if icon is not None:
-            self.add_child(icon)
-            self.icon = icon
+            self.set_icon(icon)
         if popup is not None:
             self.add_child(popup if isinstance(popup, Popup) else Popup(str(popup)))
         if tooltip is not None:
@@ -432,6 +480,20 @@ class Marker(MacroElement):
             self.add_child(self.SetIcon(marker=self, icon=self.icon))
         super().render()
 
+    def set_icon(self, icon):
+        """Set the icon for this Marker"""
+        super().add_child(icon)
+        self.icon = icon
+
+    def add_child(self, child, name=None, index=None):
+        import folium.features as features
+
+        if isinstance(child, (Icon, features.CustomIcon, features.DivIcon)):
+            self.set_icon(child)
+        else:
+            super().add_child(child, name, index)
+        return self
+
 
 class Popup(MacroElement):
     """Create a Popup instance that can be linked to a Layer.
