@@ -11,6 +11,7 @@ from folium.plugins.feature_group_sub_group import FeatureGroupSubGroup
 from folium.plugins.float_image import FloatImage
 from folium.plugins.fullscreen import Fullscreen
 from folium.plugins.geocoder import Geocoder
+from folium.plugins.geoman import GeoMan
 from folium.plugins.groupedlayercontrol import GroupedLayerControl
 from folium.plugins.heat_map import HeatMap
 from folium.plugins.heat_map_withtime import HeatMapWithTime
@@ -49,6 +50,7 @@ __all__ = [
     "FloatImage",
     "Fullscreen",
     "Geocoder",
+    "GeoMan",
     "GroupedLayerControl",
     "HeatMap",
     "HeatMapWithTime",
