@@ -1,8 +1,8 @@
 from branca.element import MacroElement
-from jinja2 import Template
 
 from folium.elements import JSCSSMixin
-from folium.utilities import parse_options
+from folium.template import Template
+from folium.utilities import remove_empty
 
 
 class Fullscreen(JSCSSMixin, MacroElement):
@@ -31,7 +31,7 @@ class Fullscreen(JSCSSMixin, MacroElement):
         """
         {% macro script(this, kwargs) %}
             L.control.fullscreen(
-                {{ this.options|tojson }}
+                {{ this.options|tojavascript }}
             ).addTo({{this._parent.get_name()}});
         {% endmacro %}
         """
@@ -40,13 +40,13 @@ class Fullscreen(JSCSSMixin, MacroElement):
     default_js = [
         (
             "Control.Fullscreen.js",
-            "https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.js",
+            "https://cdn.jsdelivr.net/npm/leaflet.fullscreen@3.0.0/Control.FullScreen.min.js",
         )
     ]
     default_css = [
         (
             "Control.FullScreen.css",
-            "https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.css",
+            "https://cdn.jsdelivr.net/npm/leaflet.fullscreen@3.0.0/Control.FullScreen.css",
         )
     ]
 
@@ -60,7 +60,7 @@ class Fullscreen(JSCSSMixin, MacroElement):
     ):
         super().__init__()
         self._name = "Fullscreen"
-        self.options = parse_options(
+        self.options = remove_empty(
             position=position,
             title=title,
             title_cancel=title_cancel,
